/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: RegistryModelLocator.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.registry.model {

    import com.adobe.cairngorm.model.IModelLocator;
    
    import mx.collections.ArrayCollection;
    
    import org.ow2.easybeans.console.registry.business.GetRegistryInfoDelegate;
    import org.ow2.easybeans.console.registry.business.IRegistryInfoDelegate;
    import org.ow2.easybeans.console.registry.locale.LocaleObject;

/**
 * Defines the model used in Registry.
 * @author Florent Benoit
 */
[Bindable]
public class RegistryModelLocator implements IModelLocator {

        /**
        * Unique instance of this model locator.
        */
        private static var unique : RegistryModelLocator;

        /**
         * Link to the Registry Info Delegate object.
         */
         private var registryInfoDelegate : IRegistryInfoDelegate;

        /**
         * Object managing locales.
         */
        private var localeObject : LocaleObject;

         /**
          * Data for each protocol.
          */
         [ArrayElementType(RegistryProtocolVO)]
        public var registryInfo : ArrayCollection;

    /**
     * The unique ID of this component
     *
     * @internal
     *   Used to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public var componentID : String = UIDUtil.createUID();

        /**
         * Constructor shouldn't be public but AS3 doesn't allow this.
         */
        public function RegistryModelLocator() {
            super();

            if (unique != null ) {
                throw new Error( "Only one instance of RegistryModelLocator should be built with singleton pattern" );
            }

            this.localeObject = new LocaleObject();
            
            this.registryInfoDelegate = new GetRegistryInfoDelegate();

        }

        /**
         * @return the unique instance of this model locator.
         */
        public static function getInstance() : RegistryModelLocator {

            // Lazy initialization
            if (unique == null ) {
                unique = new RegistryModelLocator();
            }

            // return unique instance
            return unique;
        }


       /**
         * @return the Delegate object.
         */
        public function getRegistryInfoDelegate() : IRegistryInfoDelegate {
            return registryInfoDelegate;
        }
        
        public function get locale() : LocaleObject {
            return localeObject;
        }

        public function set locale(localeObject : LocaleObject): void {
            this.localeObject = localeObject;
        }

    }

}
