/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: RegistryClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.registry.view {
    import com.adobe.cairngorm.control.CairngormEventDispatcher;
    
    import mx.collections.ArrayCollection;
    import mx.collections.Sort;
    import mx.collections.SortField;
    import mx.containers.HBox;
    import mx.containers.TabNavigator;
    import mx.containers.VBox;
    import mx.controls.DataGrid;
    import mx.controls.Label;
    import mx.controls.Text;
    import mx.events.FlexEvent;
    
    import org.ow2.easybeans.console.registry.event.GetRegistryInfoEvent;
    import org.ow2.easybeans.console.registry.event.RegistryInfoUpdatedEvent;
    import org.ow2.easybeans.console.registry.model.RegistryModelLocator;
    import org.ow2.easybeans.console.registry.vo.RegistryProtocolVO;

    

/**
 * Defines the parent class of the MXML component.
 * @author Florent Benoit
 */
public class RegistryClass extends HBox {

        /**
         * Model used for the Registry.
         */
        [Bindable]
        public var model : RegistryModelLocator = RegistryModelLocator.getInstance();


        /**
         * Tab Navigator
         */
        [Bindable]
        public var tabNavigator : TabNavigator; 

        /**
         * Default constructor.
         */
        public function RegistryClass () : void {
            addEventListener(FlexEvent.CREATION_COMPLETE, getRegistryInfo);
            CairngormEventDispatcher.getInstance().addEventListener(RegistryInfoUpdatedEvent.EVENT_REGISTRYINFO_RECEIVED, registryUpdated); 
        }

        /**
         * Handler called when registry info have been updated.
         */
        private function registryUpdated(event : Object):void {
            // Need to add tabs in the tab navigator if not here
            var children : Array = tabNavigator.getChildren();
            
            // If children, remove them
            if (children.length > 0) {
                tabNavigator.removeAllChildren();
            }
           
            // need to create them
            var model : RegistryModelLocator = RegistryModelLocator.getInstance();
            var length : int = model.registryInfo.length;
            if (length > 0) {
                    // For each protocol, add a new tab
                    for each (var protocolInfo:RegistryProtocolVO in model.registryInfo) {
                        // Create tab and add it to the parent
                        var tabEntry : HBox = new HBox();
                        tabNavigator.addChild(tabEntry);
                        
                        // Set size
                        tabEntry.percentWidth = 100;
                        tabEntry.percentHeight = 100;
                        
                        // vertical box
                        var verticalBox : VBox = new VBox();
                        tabEntry.addChild(verticalBox);
                        verticalBox.percentWidth = 100;
                        verticalBox.percentHeight = 100;
                        verticalBox.setStyle("paddingLeft", 10);
                        verticalBox.setStyle("paddingRight", 10);
                        verticalBox.setStyle("paddingTop", 10);
                        verticalBox.setStyle("paddingBottom", 10);
                        
                        
                        // Set title
                        tabEntry.label = protocolInfo.name;
                        
                        // Add providerURL
                        var horizontalBox : HBox = new HBox();
                        verticalBox.addChild(horizontalBox);
                        var label:Label = new Label();
                        label.text = "Provider URL:";
                        horizontalBox.addChild(label);
                        var text:Text = new Text();
                        text.text = protocolInfo.providerURL;
                        horizontalBox.addChild(text);
                        
                        // Add list of JNDI names
                        var dataGrid : DataGrid = new DataGrid();
                        verticalBox.addChild(dataGrid);
                        
                        // Setup datagrid
                        dataGrid.allowMultipleSelection= false;
                        dataGrid.horizontalScrollPolicy = "auto";
                        dataGrid.sortableColumns = true;
                        dataGrid.percentWidth = 100;
                        dataGrid.percentHeight = 100;
                        dataGrid.rowCount=10;

                        // Extract data                        
                        var col:ArrayCollection = new ArrayCollection();
                        for each (var name:String in protocolInfo.jndiNames) {
                            col.addItem({Name: name});                       
                        }

                        // Sort elements
                        var sort:Sort = new Sort();
                        sort.fields = [new SortField("Name", true)];
                        col.sort = sort;
                        col.refresh();

                        // set provider
                        dataGrid.dataProvider = col;
                    }
            } 
            
            
            
        }


        /**
         * Handler called when object is created.
         */
        protected function getRegistryInfo (event:FlexEvent):void {
            CairngormEventDispatcher.getInstance().dispatchEvent( new GetRegistryInfoEvent() );
        }

}
}
